# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`nft`](#nft): Initialize nft, the noreply nftables puppet module.  This sets up the staging directory and files and installs nftables and activates the ser

### Defined types

* [`nft::chain`](#nft--chain): Create a nftables chain in the nftables config file  Chains come in two forms: base chains are chains that the kernel hooks into while proces
* [`nft::file`](#nft--file): Create a chain for nft to stage content in  This is a module internal type, you should never need to use it from outside.
* [`nft::fragment`](#nft--fragment): Add a fragment to a staging file created by nft::file  This is a module internal type, you should never need to use it from outside.
* [`nft::object`](#nft--object): Create an nftables.conf "define" set.  This is static and can then be referenced in other nftables like things  Implicitly, we also create __
* [`nft::object_impl`](#nft--object_impl): The backend implementation the nft::object front.  This type knows its address types.  An object may not have address elements/objects and no
* [`nft::rule`](#nft--rule): Create a rule in our nftables config  Rules live in chains that belong to tables.  Confer to the nftables documentation for how to write rule
* [`nft::set`](#nft--set): Create an nftables named set in the nftables config file  Example:   nft::set{ 'authnft-pape':     type  => 'ipv4_addr',     flags => [ 'time
* [`nft::simple`](#nft--simple): A simple rule from IP addresses to a TCP or UDP port  This is meant to abstract the most common instances of nftables rules. It will never be

### Functions

* [`nft::af_filter_address_set_object`](#nft--af_filter_address_set_object): Find the elements of a given address family for an address, set, or object as passed into nft::simnple  For object references, replace by the

### Data types

* [`Nft::AddressFamily`](#Nft--AddressFamily): An nftables address family cf. https://www.netfilter.org/projects/nftables/manpage.html or https://www.mankier.com/8/nft#Address_Families
* [`Nft::ChainHook`](#Nft--ChainHook): The list of chain hooks in nftables cf. https://www.netfilter.org/projects/nftables/manpage.html or https://www.mankier.com/8/nft#Address_Fam
* [`Nft::ChainPriority`](#Nft--ChainPriority): The priority strings that are accepted for base chains cf. https://www.netfilter.org/projects/nftables/manpage.html or https://www.mankier.co
* [`Nft::ChainType`](#Nft--ChainType): The nftables chain types cf. https://www.netfilter.org/projects/nftables/manpage.html or https://www.mankier.com/8/nft#Chains
* [`Nft::Objectdefine`](#Nft--Objectdefine): Nftables.conf define, during definition (i.e. without the $) cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets#nftables.conf_syntax
* [`Nft::Objectreference`](#Nft--Objectreference): Nftables.conf define when used (i.e. wit the $) cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets#nftables.conf_syntax
* [`Nft::Objectreference_internal`](#Nft--Objectreference_internal): Nftables.conf define when used (i.e. wit the $) cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets#nftables.conf_syntax  Including in
* [`Nft::Port`](#Nft--Port): Nftables.conf port, either a number of a string from /etc/services
* [`Nft::Portrange`](#Nft--Portrange): Nftables.conf portrange
* [`Nft::Setflag`](#Nft--Setflag): Nftables named set flags cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets
* [`Nft::Setname`](#Nft--Setname): Nftables name of a named set cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets
* [`Nft::Setreference`](#Nft--Setreference): Nftables reference to a set with @<name> cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets
* [`Nft::Settype`](#Nft--Settype): Nftables named set types cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets
* [`Nft::String`](#Nft--String): What defines an nftables string cf. https://www.netfilter.org/projects/nftables/manpage.html or https://www.mankier.com/8/nft#Data_Types

## Classes

### <a name="nft"></a>`nft`

Initialize nft, the noreply nftables puppet module.

This sets up the staging directory and files and installs nftables
and activates the service.  No policy is shipped with this module,
it needs to be provided by other puppet code using nft.

#### Parameters

The following parameters are available in the `nft` class:

* [`dir_test`](#-nft--dir_test)
* [`dir_prod`](#-nft--dir_prod)
* [`main_test`](#-nft--main_test)
* [`main_prod`](#-nft--main_prod)
* [`flush_ruleset`](#-nft--flush_ruleset)
* [`service_enable`](#-nft--service_enable)
* [`service_ensure`](#-nft--service_ensure)

##### <a name="-nft--dir_test"></a>`dir_test`

Data type: `Stdlib::AbsolutePath`

Staging directory

Default value: `'/etc/.nftables-staging'`

##### <a name="-nft--dir_prod"></a>`dir_prod`

Data type: `Stdlib::AbsolutePath`

Production directory for the live, tested rules

Default value: `'/etc/nftables'`

##### <a name="-nft--main_test"></a>`main_test`

Data type: `Stdlib::AbsolutePath`

Staging config file that sources everything else

Default value: `"${dir_test}/main.conf"`

##### <a name="-nft--main_prod"></a>`main_prod`

Data type: `Stdlib::AbsolutePath`

Production config file that sources everything else

Default value:

```puppet
$facts['os']['family'] ? {
    'Debian' => '/etc/nftables.conf',
    'RedHat' => '/etc/sysconfig/nftables.conf',
    default  => '/etc/nftables.conf'
```

##### <a name="-nft--flush_ruleset"></a>`flush_ruleset`

Data type: `Variant[Boolean, String]`

Whether to flush the ruleset at the start, or which tables to flush.
In general, this probably always wants to be true.  However, if you manage
for instance the inet table with this module and say the ip table by some
other means, this can be set to just 'inet'.

Default value: `true`

##### <a name="-nft--service_enable"></a>`service_enable`

Data type: `Boolean`

enable the nftables service

Default value: `true`

##### <a name="-nft--service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

whether to have the service running or stopped

Default value: `if ($service_enable) { 'running' } else { 'stopped'`

## Defined types

### <a name="nft--chain"></a>`nft::chain`

Create a nftables chain in the nftables config file

Chains come in two forms: base chains are chains that the kernel hooks into
while processing a packet.  These chains may then also jump to non-base-chains.
See the netfilter documentation for more details.

#### Examples

##### 

```puppet
nft::chain{ 'input': }
nft::chain{ 'forward': }
nft::chain{ 'output': }

nft::chain{ 'log_reject_drop':
  rules => [
    "limit rate 5/minute burst 5 packets log flags all counter",
    "limit rate 60/minute burst 120 packets meta l4proto tcp counter reject with tcp reset",
    "limit rate 60/minute burst 120 packets meta l4proto != tcp counter reject with icmpx type admin-prohibited",
    'counter drop',
  ]
}
```

#### Parameters

The following parameters are available in the `nft::chain` defined type:

* [`chain`](#-nft--chain--chain)
* [`af`](#-nft--chain--af)
* [`table`](#-nft--chain--table)
* [`base_chain`](#-nft--chain--base_chain)
* [`hook`](#-nft--chain--hook)
* [`type`](#-nft--chain--type)
* [`priority`](#-nft--chain--priority)
* [`rules_order`](#-nft--chain--rules_order)
* [`rules`](#-nft--chain--rules)

##### <a name="-nft--chain--chain"></a>`chain`

Data type: `Nft::String`

The name of the chain

Default value: `$name`

##### <a name="-nft--chain--af"></a>`af`

Data type: `Nft::AddressFamily`

Address family (inet, ip, ip6, etc)

Default value: `'inet'`

##### <a name="-nft--chain--table"></a>`table`

Data type: `Nft::String`

The name of the table

Default value: `'filter'`

##### <a name="-nft--chain--base_chain"></a>`base_chain`

Data type: `Boolean`

Whether this is a base chain

If so, we add hooks and need to define hook, type, and priority.

Default value: `$chain =~ Nft::ChainHook`

##### <a name="-nft--chain--hook"></a>`hook`

Data type: `Optional[Nft::ChainHook]`

If a base chain, the name of the hook

Default value: `if $base_chain { $chain } else { undef`

##### <a name="-nft--chain--type"></a>`type`

Data type: `Optional[Nft::ChainType]`

If a base chain, the type of this chain (filter, nat, route)

Default value: `if $base_chain { $table } else { undef`

##### <a name="-nft--chain--priority"></a>`priority`

Data type: `Optional[Nft::ChainPriority]`

If a base chain, the priority of this chain.

Default value:

```puppet
if $base_chain {
    "${table}-${chain}" ? {
      'nat-prerouting'    => 'dstnat',
      'nat-postrouting'   => 'srcnat',
      'filter-prerouting' => 'raw',
      default             => 'filter' } } else { undef
```

##### <a name="-nft--chain--rules_order"></a>`rules_order`

Data type: `Integer`

If we pass a set of rules to this chain here, at what order number to add it to the concat.

Default value: `0`

##### <a name="-nft--chain--rules"></a>`rules`

Data type: `Optional[Array[String]]`

A list of rules to pass here directly.  More can be added later using nft::rule.

Default value: `undef`

### <a name="nft--file"></a>`nft::file`

Create a chain for nft to stage content in

This is a module internal type, you should never need to use it from outside.

#### Parameters

The following parameters are available in the `nft::file` defined type:

* [`filename`](#-nft--file--filename)
* [`extension`](#-nft--file--extension)

##### <a name="-nft--file--filename"></a>`filename`

Data type: `String`

Base name of the file (without path or extension)

Default value: `regsubst($name, '[^a-zA-Z0-9.,_=-]', '_' ,'G')`

##### <a name="-nft--file--extension"></a>`extension`

Data type: `String`

String to append to the filename

Default value: `'.nft'`

### <a name="nft--fragment"></a>`nft::fragment`

Add a fragment to a staging file created by nft::file

This is a module internal type, you should never need to use it from outside.

#### Parameters

The following parameters are available in the `nft::fragment` defined type:

* [`target`](#-nft--fragment--target)
* [`source`](#-nft--fragment--source)
* [`content`](#-nft--fragment--content)
* [`order`](#-nft--fragment--order)

##### <a name="-nft--fragment--target"></a>`target`

Data type: `String`

Where in our nftables config this should end up with.
Usually this is a per-chain file.

##### <a name="-nft--fragment--source"></a>`source`

Data type: `Optional[String]`

Source to pass to concat::fragment

Default value: `undef`

##### <a name="-nft--fragment--content"></a>`content`

Data type: `Optional[String]`

Content to pass to concat::fragment

Default value: `undef`

##### <a name="-nft--fragment--order"></a>`order`

Data type: `Optional[Integer]`

Order to pass to concat::fragment

Default value: `undef`

### <a name="nft--object"></a>`nft::object`

Create an nftables.conf "define" set.  This is static and can then be
referenced in other nftables like things

Implicitly, we also create __4_<x> and __6_<y> objects with just the ipv4 and
ipv6 elements of the object.  If the object is not an address object, these
will usually be empty.

Example:
  nft::object{ 'SIMPLE_SET':
    elements => [ '192.168.1.1', '192.168.1.2' ],
  }
Example:
  nft::object{ 'CDN':
    elements => [ '$CDN_EDGE', '$CDN_MONITORS' ]
  }

#### Parameters

The following parameters are available in the `nft::object` defined type:

* [`object_name`](#-nft--object--object_name)
* [`elements`](#-nft--object--elements)

##### <a name="-nft--object--object_name"></a>`object_name`

Data type: `Nft::Objectdefine`

The name of the object, in capital letters.

Default value: `$name`

##### <a name="-nft--object--elements"></a>`elements`

Data type: `Array[String]`

A list of elements in this set.
Currently, no syntax checking is done in the puppet module.

Default value: `[]`

### <a name="nft--object_impl"></a>`nft::object_impl`

The backend implementation the nft::object front.

This type knows its address types.

An object may not have address elements/objects and non-adress
elements/objects at the same time.

Example:
  nft::object_impl{ 'SIMPLE_SET':
    ipv4_elements => [ '192.168.1.1', '192.168.1.2' ],
  }

#### Parameters

The following parameters are available in the `nft::object_impl` defined type:

* [`object_name`](#-nft--object_impl--object_name)
* [`ipv4_elements`](#-nft--object_impl--ipv4_elements)
* [`ipv6_elements`](#-nft--object_impl--ipv6_elements)
* [`ipv4_objects`](#-nft--object_impl--ipv4_objects)
* [`ipv6_objects`](#-nft--object_impl--ipv6_objects)
* [`non_addr_elements`](#-nft--object_impl--non_addr_elements)
* [`non_addr_objects`](#-nft--object_impl--non_addr_objects)
* [`have_ipv4`](#-nft--object_impl--have_ipv4)
* [`have_ipv6`](#-nft--object_impl--have_ipv6)

##### <a name="-nft--object_impl--object_name"></a>`object_name`

Data type: `Nft::Objectdefine`

The name of the object, in capital letters.

Default value: `$name`

##### <a name="-nft--object_impl--ipv4_elements"></a>`ipv4_elements`

Data type: `Array[Stdlib::IP::Address::V4]`

IPv4 Addresses in this object

Default value: `[]`

##### <a name="-nft--object_impl--ipv6_elements"></a>`ipv6_elements`

Data type: `Array[Stdlib::IP::Address::V6]`

IPv6 Addresses in this object

Default value: `[]`

##### <a name="-nft--object_impl--ipv4_objects"></a>`ipv4_objects`

Data type: `Array[Nft::Objectdefine]`

IPv4 Object names referenced by this object

Default value: `[]`

##### <a name="-nft--object_impl--ipv6_objects"></a>`ipv6_objects`

Data type: `Array[Nft::Objectdefine]`

IPv6 Object names referenced by this object

Default value: `[]`

##### <a name="-nft--object_impl--non_addr_elements"></a>`non_addr_elements`

Data type: `Array[String]`

Non-Address elements in this object

Default value: `[]`

##### <a name="-nft--object_impl--non_addr_objects"></a>`non_addr_objects`

Data type: `Array[Nft::Objectdefine]`

Non-Address Object names referenced by this object

Default value: `[]`

##### <a name="-nft--object_impl--have_ipv4"></a>`have_ipv4`

Data type: `Boolean`

Is an object that includes ipv4 elements directly or via referenced objects
This must be set by the caller, as computing it here is too late since objects
get evaluated lazily, and when we access this by e.g. the af_filter_address_set_object
function, we need the correct values.

##### <a name="-nft--object_impl--have_ipv6"></a>`have_ipv6`

Data type: `Boolean`

Is an object that includes ipv6 elements directly or via referenced objects
Just like have_ipv4, this must be set by the caller and for the same reasons.

### <a name="nft--rule"></a>`nft::rule`

Create a rule in our nftables config

Rules live in chains that belong to tables.  Confer to the nftables
documentation for how to write rules.  Also see nft::simple for a more
abstracted way of adding rules.

#### Examples

##### 

```puppet
nft::chain{ 'input': }
nft::chain{ 'services_tcp': }

nft::rule{
  'iif lo counter accept': order => 100;
  'meta l4proto icmp counter accept': order => 101;
  'meta l4proto ipv6-icmp counter accept': order => 101;
  'ct state established,related counter accept': order => 110;
  'meta l4proto tcp counter jump services_tcp': order => 20;
  'counter drop': order => 9000;
}

nft::rule{ 'allow-https':
  rule  => 'tcp dport https counter accept',
  chain => 'services_tcp',
}
```

#### Parameters

The following parameters are available in the `nft::rule` defined type:

* [`rule`](#-nft--rule--rule)
* [`chain`](#-nft--rule--chain)
* [`af`](#-nft--rule--af)
* [`table`](#-nft--rule--table)
* [`description`](#-nft--rule--description)
* [`order`](#-nft--rule--order)

##### <a name="-nft--rule--rule"></a>`rule`

Data type: `Variant[String,Array[String]]`

The actual nftables rule.

Default value: `$name`

##### <a name="-nft--rule--chain"></a>`chain`

Data type: `Nft::String`

The name of the chain

Default value: `'input'`

##### <a name="-nft--rule--af"></a>`af`

Data type: `Nft::AddressFamily`

Address family (inet, ip, ip6, etc)

Default value: `'inet'`

##### <a name="-nft--rule--table"></a>`table`

Data type: `Nft::String`

The name of the table

Default value: `'filter'`

##### <a name="-nft--rule--description"></a>`description`

Data type: `Optional[String]`

A description or comment for this rule to put into the nftables config

Default value: `undef`

##### <a name="-nft--rule--order"></a>`order`

Data type: `Integer`

Where to put this rule in the concat file

Default value: `200`

### <a name="nft--set"></a>`nft::set`

Create an nftables named set in the nftables config file

Example:
  nft::set{ 'authnft-pape':
    type  => 'ipv4_addr',
    flags => [ 'timeout' ],
  }

#### Parameters

The following parameters are available in the `nft::set` defined type:

* [`setname`](#-nft--set--setname)
* [`af`](#-nft--set--af)
* [`table`](#-nft--set--table)
* [`type`](#-nft--set--type)
* [`flags`](#-nft--set--flags)

##### <a name="-nft--set--setname"></a>`setname`

Data type: `Nft::Setname`

The name of the set

Default value: `$name`

##### <a name="-nft--set--af"></a>`af`

Data type: `Nft::AddressFamily`

Address family (inet, ip, ip6, etc)

Default value: `'inet'`

##### <a name="-nft--set--table"></a>`table`

Data type: `Nft::String`

The name of the table

Default value: `'filter'`

##### <a name="-nft--set--type"></a>`type`

Data type: `Nft::Settype`

The type of the objects in this set (cf Nft::Settype)

##### <a name="-nft--set--flags"></a>`flags`

Data type: `Array[Nft::Setflag]`

A list of flags for this set (cf Nft::Setflags)

Default value: `[]`

### <a name="nft--simple"></a>`nft::simple`

A simple rule from IP addresses to a TCP or UDP port

This is meant to abstract the most common instances of nftables rules.
It will never be a way to do them all, nor is that the intention.

#### Examples

##### 

```puppet
nft::simple { 'allow-web':
  dport   => [80, 443],
}
```

##### 

```puppet
nft::simple { 'allow-ssh':
  dport   => 22,
  iifname => 'mgmt',
}
```

##### allow-ssh

```puppet
nft::simple { 'allow-ssh':
  iifname => 'mgmt',
  dport   => 22,
  saddr   => ['10.0.0.0/8', '172.16.0.0/12'],
}
```

##### from networks

```puppet
nft::simple{ 'allow-mta-submission':
  saddr => $my_networks,
  dport => 587,
}
```

##### in a different chain

```puppet
nft::simple{ "allow-extra-ssh":
  chain => 'ssh-filter',
  saddr => $src_address,
}
```

##### allow-dns

```puppet
nft::simple { 'allow-dns':
  dport   => 'domain',
  proto   => ['tcp', 'udp'],
}
```

##### 

```puppet
nft::simple { 'from-guest-wifi':
  iifname => 'wlan0',
  action  => 'jump from-guests',
}
```

##### # do not track the incoming traffic

```puppet
nft::simple { "prerouting-notrack-${title}-${proto}":
  chain   => 'prerouting',
  iifname => $interface,
  proto   => $proto,
  dport   => $incoming_dport,
  sport   => $incoming_sport,
  action  => 'notrack',
}
```

##### nat

```puppet
nft::chain { 'prerouting':
  table => 'nat',
}
nft::simple { 'redirect-incoming-gerrit-ssh':
  chain  => 'prerouting',
  table  => 'nat',
  daddr  => $gerrit_service_ip,
  dport  => 22,
  action => "redirect to :${gerrit_ssh_port}",
}
```

#### Parameters

The following parameters are available in the `nft::simple` defined type:

* [`saddr`](#-nft--simple--saddr)
* [`daddr`](#-nft--simple--daddr)
* [`saddr_not`](#-nft--simple--saddr_not)
* [`daddr_not`](#-nft--simple--daddr_not)
* [`dport`](#-nft--simple--dport)
* [`sport`](#-nft--simple--sport)
* [`proto`](#-nft--simple--proto)
* [`chain`](#-nft--simple--chain)
* [`af`](#-nft--simple--af)
* [`table`](#-nft--simple--table)
* [`description`](#-nft--simple--description)
* [`iif`](#-nft--simple--iif)
* [`oif`](#-nft--simple--oif)
* [`iifname`](#-nft--simple--iifname)
* [`oifname`](#-nft--simple--oifname)
* [`order`](#-nft--simple--order)
* [`counter`](#-nft--simple--counter)
* [`log_rule`](#-nft--simple--log_rule)
* [`action`](#-nft--simple--action)
* [`snat`](#-nft--simple--snat)

##### <a name="-nft--simple--saddr"></a>`saddr`

Data type:

```puppet
Optional[Variant[ Stdlib::IP::Address, Nft::Objectreference, Nft::Setreference,
                    Array[Variant[Stdlib::IP::Address, Nft::Objectreference]]]]
```

A list of source addresses.
If not provided, allow from everywhere, but see the explanation at daddr.

Default value: `undef`

##### <a name="-nft--simple--daddr"></a>`daddr`

Data type:

```puppet
Optional[Variant[ Stdlib::IP::Address, Nft::Objectreference, Nft::Setreference,
                    Array[Variant[Stdlib::IP::Address, Nft::Objectreference]]]]
```

A list of destination addresses.
If not provided, allow to everywhere.

Note that the interaction with different address families is tricky.
- If saddr and daddr are empty, then IPv4 and IPv6 are allowed.
- If saddr and/or daddr only have addresses of one address family, then
  only that address family is allowed.
- If the union of saddr and daddr have both IPv4 and IPv6, then both
  are processed, with saddr and daddr filtering based on the given lists,
  with an empty list (after AF filtering) meaning everything is allowed.

Default value: `undef`

##### <a name="-nft--simple--saddr_not"></a>`saddr_not`

Data type:

```puppet
Optional[Variant[ Stdlib::IP::Address, Nft::Objectreference, Nft::Setreference,
                    Array[Variant[Stdlib::IP::Address, Nft::Objectreference]]]]
```

A negative list of source addresses

Default value: `undef`

##### <a name="-nft--simple--daddr_not"></a>`daddr_not`

Data type:

```puppet
Optional[Variant[ Stdlib::IP::Address, Nft::Objectreference, Nft::Setreference,
                    Array[Variant[Stdlib::IP::Address, Nft::Objectreference]]]]
```

A negative list of destination addresses

Default value: `undef`

##### <a name="-nft--simple--dport"></a>`dport`

Data type: `Optional[Variant[Nft::Port, Nft::Portrange, Array[Variant[Nft::Port, Nft::Portrange], 1]]]`

A target port (port number or service name from /etc/services),
A range of ports ("<number>-<number>" as string),
or a list of these.
If not provided, do not match on ports

Default value: `undef`

##### <a name="-nft--simple--sport"></a>`sport`

Data type: `Optional[Variant[Nft::Port, Nft::Portrange, Array[Variant[Nft::Port, Nft::Portrange], 1]]]`

Source ports in the same way as dport.

Default value: `undef`

##### <a name="-nft--simple--proto"></a>`proto`

Data type: `Optional[Variant[Enum['tcp', 'udp'], Integer, Array[Enum['tcp', 'udp']]]]`

Whether this is TCP or UDP or something else (given protocol number).
Providing sport and dport may or may not make sense for a given protocol.
Defaults to 'tcp' if ports are given, none otherwise.
Using a set (i.e. list of ['tcp', 'udp']) is also possible.

Default value: `if ($sport !~ Undef or $dport !~ Undef) { 'tcp' } else { undef`

##### <a name="-nft--simple--chain"></a>`chain`

Data type: `Nft::String`

The name of the chain

Default value: `'input'`

##### <a name="-nft--simple--af"></a>`af`

Data type: `Nft::AddressFamily`

Address family (inet, ip, ip6, etc)

Default value: `'inet'`

##### <a name="-nft--simple--table"></a>`table`

Data type: `Nft::String`

The name of the table

Default value: `'filter'`

##### <a name="-nft--simple--description"></a>`description`

Data type: `Optional[String]`

A description or comment for this rule to put into the nftables config

Default value: `undef`

##### <a name="-nft--simple--iif"></a>`iif`

Data type: `Optional[Variant[String,Array[String, 1]]]`

A list of in-interfaces to match;  if not provided, do not match on interfaces.

Default value: `undef`

##### <a name="-nft--simple--oif"></a>`oif`

Data type: `Optional[Variant[String,Array[String, 1]]]`

A list of out-interfaces to match;  if not provided, do not match on interfaces.

Default value: `undef`

##### <a name="-nft--simple--iifname"></a>`iifname`

Data type: `Optional[Variant[String,Array[String, 1]]]`

A list of in-interface-namess to match;  if not provided, do not match on interface names.

Default value: `undef`

##### <a name="-nft--simple--oifname"></a>`oifname`

Data type: `Optional[Variant[String,Array[String, 1]]]`

A list of out-interface-names to match;  if not provided, do not match on interface names.

Default value: `undef`

##### <a name="-nft--simple--order"></a>`order`

Data type: `Optional[Integer]`

Where to put this rule in the concat file

Default value: `undef`

##### <a name="-nft--simple--counter"></a>`counter`

Data type: `Boolean`

Whether to add a counter to this rule

Default value: `true`

##### <a name="-nft--simple--log_rule"></a>`log_rule`

Data type: `Optional[Pattern[/\Alog.*\z/]]`

Log rule to add before the final action

Default value: `undef`

##### <a name="-nft--simple--action"></a>`action`

Data type: `Optional[String]`

What to do with matches (accept, drop, ..)

Default value: `undef`

##### <a name="-nft--simple--snat"></a>`snat`

Data type: `Optional[Variant[Stdlib::IP::Address, Nft::Objectreference]]`

Address to source nat to (mutually exclusive with other action items)

Default value: `undef`

## Functions

### <a name="nft--af_filter_address_set_object"></a>`nft::af_filter_address_set_object`

Type: Puppet Language

Find the elements of a given address family for an address, set, or object as passed into nft::simnple

For object references, replace by the corresponding __<x>_ object (cf. nft::object)

#### `nft::af_filter_address_set_object(Optional[Variant[ Stdlib::IP::Address, Nft::Setreference, Nft::Objectreference,
                    Array[Variant[Stdlib::IP::Address, Nft::Objectreference]]]] $filter_element, Enum['v4', 'v6'] $test_target)`

Find the elements of a given address family for an address, set, or object as passed into nft::simnple

For object references, replace by the corresponding __<x>_ object (cf. nft::object)

Returns: `Variant[
    Array[Variant[Stdlib::IP::Address::V4, Nft::Objectreference, Nft::Objectreference_internal]],
    Array[Variant[Stdlib::IP::Address::V6, Nft::Objectreference, Nft::Objectreference_internal]],
    Array[Nft::Setreference, 1, 1]
  ]` The addresses and sets in that list of the given address family

##### `filter_element`

Data type:

```puppet
Optional[Variant[ Stdlib::IP::Address, Nft::Setreference, Nft::Objectreference,
                    Array[Variant[Stdlib::IP::Address, Nft::Objectreference]]]]
```

The address, set, or list to filter

##### `test_target`

Data type: `Enum['v4', 'v6']`

v4 or v6

## Data types

### <a name="Nft--AddressFamily"></a>`Nft::AddressFamily`

An nftables address family
cf. https://www.netfilter.org/projects/nftables/manpage.html
or https://www.mankier.com/8/nft#Address_Families

Alias of `Enum['inet', 'ip', 'ip6', 'arp', 'bridge', 'netdev']`

### <a name="Nft--ChainHook"></a>`Nft::ChainHook`

The list of chain hooks in nftables
cf. https://www.netfilter.org/projects/nftables/manpage.html
or https://www.mankier.com/8/nft#Address_Families

Alias of `Enum['ingress', 'prerouting', 'input', 'forward', 'output', 'postrouting']`

### <a name="Nft--ChainPriority"></a>`Nft::ChainPriority`

The priority strings that are accepted for base chains
cf. https://www.netfilter.org/projects/nftables/manpage.html
or https://www.mankier.com/8/nft#Chains

Alias of `Variant[Integer, Enum['raw', 'mangle', 'dstnat', 'filter', 'security', 'srcnat']]`

### <a name="Nft--ChainType"></a>`Nft::ChainType`

The nftables chain types
cf. https://www.netfilter.org/projects/nftables/manpage.html
or https://www.mankier.com/8/nft#Chains

Alias of `Enum['filter', 'nat', 'route']`

### <a name="Nft--Objectdefine"></a>`Nft::Objectdefine`

Nftables.conf define, during definition (i.e. without the $)
cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets#nftables.conf_syntax

Alias of `Pattern[/\A[A-Z][A-Z0-9_]*\z/]`

### <a name="Nft--Objectreference"></a>`Nft::Objectreference`

Nftables.conf define when used (i.e. wit the $)
cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets#nftables.conf_syntax

Alias of `Pattern[/\A\$[A-Z][A-Z0-9_]*\z/]`

### <a name="Nft--Objectreference_internal"></a>`Nft::Objectreference_internal`

Nftables.conf define when used (i.e. wit the $)
cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets#nftables.conf_syntax

Including internal objects

Alias of `Pattern[/\A\$__[46]_[A-Z][A-Z0-9_]*\z/]`

### <a name="Nft--Port"></a>`Nft::Port`

Nftables.conf port, either a number of a string from /etc/services

Alias of `Variant[Stdlib::Port, Pattern[/\A[a-z][a-z0-9-]*\z/]]`

### <a name="Nft--Portrange"></a>`Nft::Portrange`

Nftables.conf portrange

Alias of `Pattern[/\A[0-9]+-[0-9]+\z/]`

### <a name="Nft--Setflag"></a>`Nft::Setflag`

Nftables named set flags
cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets

Alias of `Enum['constant', 'interval', 'timeout']`

### <a name="Nft--Setname"></a>`Nft::Setname`

Nftables name of a named set
cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets

Alias of `Pattern[/\A[a-z][a-z0-9_-]*\z/]`

### <a name="Nft--Setreference"></a>`Nft::Setreference`

Nftables reference to a set with @<name>
cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets

Alias of `Pattern[/\A@[a-z][a-z0-9_-]*\z/]`

### <a name="Nft--Settype"></a>`Nft::Settype`

Nftables named set types
cf. https://wiki.nftables.org/wiki-nftables/index.php/Sets

Alias of `Enum['ipv4_addr', 'ipv6_addr', 'ether_addr', 'inet_proto', 'inet_service', 'mark', 'ifname']`

### <a name="Nft--String"></a>`Nft::String`

What defines an nftables string
cf. https://www.netfilter.org/projects/nftables/manpage.html
or https://www.mankier.com/8/nft#Data_Types

Alias of `Pattern[/\A[a-zA-Z_][a-zA-Z0-9\/_.-]*\z/]`

